@@ -4,26 +4,34 @@
 """ Unit tests for zeroconf._services.browser. """
 
 import logging
+import os
 import socket
 import time
-import os
 import unittest
 from threading import Event
+from typing import Iterable, Set
 from unittest.mock import patch
 
 import pytest
 
 import zeroconf as r
-from zeroconf import DNSPointer, DNSQuestion, const, current_time_millis, millis_to_seconds
 import zeroconf._services.browser as _services_browser
-from zeroconf import _core, _handlers, Zeroconf
+from zeroconf import (
+    DNSPointer,
+    DNSQuestion,
+    Zeroconf,
+    _core,
+    _handlers,
+    const,
+    current_time_millis,
+    millis_to_seconds,
+)
 from zeroconf._services import ServiceStateChange
 from zeroconf._services.browser import ServiceBrowser
 from zeroconf._services.info import ServiceInfo
 from zeroconf.asyncio import AsyncZeroconf
 
-from .. import has_working_ipv6, _inject_response, _wait_for_start
-
+from .. import _inject_response, _wait_for_start, has_working_ipv6
 
 log = logging.getLogger('zeroconf')
 original_logging_level = logging.NOTSET
@@ -98,7 +106,7 @@ def test_service_browser_started_after_zeroconf_closed():
     zc.close()
 
     with pytest.raises(RuntimeError):
-        browser = r.ServiceBrowser(zc, type_, None, listener)
+        r.ServiceBrowser(zc, type_, None, listener)
 
 
 def test_multiple_instances_running_close():
@@ -145,17 +153,17 @@ class TestServiceBrowser(unittest.TestCase):
         service_updated_event = Event()
 
         class MyServiceListener(r.ServiceListener):
-            def add_service(self, zc, type_, name) -> None:
+            def add_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
                 nonlocal service_added_count
                 service_added_count += 1
                 service_add_event.set()
 
-            def remove_service(self, zc, type_, name) -> None:
+            def remove_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
                 nonlocal service_removed_count
                 service_removed_count += 1
                 service_removed_event.set()
 
-            def update_service(self, zc, type_, name) -> None:
+            def update_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
                 nonlocal service_updated_count
                 service_updated_count += 1
                 service_info = zc.get_service_info(type_, name)
@@ -168,7 +176,7 @@ class TestServiceBrowser(unittest.TestCase):
                         socket.AF_INET6, service_v6_second_address
                     ) in service_info.addresses_by_version(r.IPVersion.V6Only)
                 assert service_info.text == service_text
-                assert service_info.server == service_server
+                assert service_info.server.lower() == service_server.lower()
                 service_updated_event.set()
 
         def mock_incoming_msg(service_state_change: r.ServiceStateChange) -> r.DNSIncoming:
@@ -333,13 +341,13 @@ class TestServiceBrowserMultipleTypes(unittest.TestCase):
         service_removed_event = Event()
 
         class MyServiceListener(r.ServiceListener):
-            def add_service(self, zc, type_, name) -> None:
+            def add_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
                 nonlocal service_added_count
                 service_added_count += 1
                 if service_added_count == 3:
                     service_add_event.set()
 
-            def remove_service(self, zc, type_, name) -> None:
+            def remove_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
                 nonlocal service_removed_count
                 service_removed_count += 1
                 if service_removed_count == 3:
@@ -419,6 +427,9 @@ class TestServiceBrowserMultipleTypes(unittest.TestCase):
             service_removed_event.wait(wait_time)
             assert service_added_count == 3
             assert service_removed_count == 3
+        except TypeError:
+            # Cannot be patched with cython as get_expiration_time is immutable
+            pass
 
         finally:
             assert len(zeroconf.listeners) == 1
@@ -494,6 +505,7 @@ def test_backoff():
                 else:
                     assert not got_query.is_set()
                 time_offset += initial_query_interval
+                assert zeroconf_browser.loop is not None
                 zeroconf_browser.loop.call_soon_threadsafe(browser._async_send_ready_queries_schedule_next)
 
         finally:
@@ -555,8 +567,8 @@ def test_asking_default_is_asking_qm_questions_after_the_first_qu():
         """Sends an outgoing packet."""
         nonlocal first_outgoing
         nonlocal second_outgoing
-        if first_outgoing is not None and second_outgoing is None:
-            second_outgoing = out
+        if first_outgoing is not None and second_outgoing is None:  # type: ignore[unreachable]
+            second_outgoing = out  # type: ignore[unreachable]
         if first_outgoing is None:
             first_outgoing = out
         old_send(out, addr=addr, port=port)
@@ -570,8 +582,8 @@ def test_asking_default_is_asking_qm_questions_after_the_first_qu():
         browser = ServiceBrowser(zeroconf_browser, type_, [on_service_state_change], delay=5)
         time.sleep(millis_to_seconds(_services_browser._FIRST_QUERY_DELAY_RANDOM_INTERVAL[1] + 120 + 5))
         try:
-            assert first_outgoing.questions[0].unicast == True
-            assert second_outgoing.questions[0].unicast == False
+            assert first_outgoing.questions[0].unicast is True  # type: ignore[union-attr]
+            assert second_outgoing.questions[0].unicast is False  # type: ignore[attr-defined]
         finally:
             browser.cancel()
             zeroconf_browser.close()
@@ -605,7 +617,7 @@ def test_asking_qm_questions():
         )
         time.sleep(millis_to_seconds(_services_browser._FIRST_QUERY_DELAY_RANDOM_INTERVAL[1] + 5))
         try:
-            assert first_outgoing.questions[0].unicast == False
+            assert first_outgoing.questions[0].unicast is False  # type: ignore[union-attr]
         finally:
             browser.cancel()
             zeroconf_browser.close()
@@ -639,7 +651,7 @@ def test_asking_qu_questions():
         )
         time.sleep(millis_to_seconds(_services_browser._FIRST_QUERY_DELAY_RANDOM_INTERVAL[1] + 5))
         try:
-            assert first_outgoing.questions[0].unicast == True
+            assert first_outgoing.questions[0].unicast is True  # type: ignore[union-attr]
         finally:
             browser.cancel()
             zeroconf_browser.close()
@@ -715,8 +727,10 @@ def test_service_browser_is_aware_of_port_changes():
     registration_name = "xxxyyy.%s" % type_
 
     callbacks = []
+
     # dummy service callback
     def on_service_state_change(zeroconf, service_type, state_change, name):
+        """Dummy callback."""
         nonlocal callbacks
         if name == registration_name:
             callbacks.append((service_type, state_change, name))
@@ -728,7 +742,7 @@ def test_service_browser_is_aware_of_port_changes():
     address = socket.inet_aton(address_parsed)
     info = ServiceInfo(type_, registration_name, 80, 0, 0, desc, "ash-2.local.", addresses=[address])
 
-    def mock_incoming_msg(records) -> r.DNSIncoming:
+    def mock_incoming_msg(records: Iterable[r.DNSRecord]) -> r.DNSIncoming:
         generated = r.DNSOutgoing(const._FLAGS_QR_RESPONSE)
         for record in records:
             generated.add_answer_at_time(record, 0)
@@ -741,7 +755,9 @@ def test_service_browser_is_aware_of_port_changes():
     time.sleep(0.1)
 
     assert callbacks == [('_hap._tcp.local.', ServiceStateChange.Added, 'xxxyyy._hap._tcp.local.')]
-    assert zc.get_service_info(type_, registration_name).port == 80
+    service_info = zc.get_service_info(type_, registration_name)
+    assert service_info is not None
+    assert service_info.port == 80
 
     info.port = 400
     _inject_response(
@@ -754,7 +770,9 @@ def test_service_browser_is_aware_of_port_changes():
         ('_hap._tcp.local.', ServiceStateChange.Added, 'xxxyyy._hap._tcp.local.'),
         ('_hap._tcp.local.', ServiceStateChange.Updated, 'xxxyyy._hap._tcp.local.'),
     ]
-    assert zc.get_service_info(type_, registration_name).port == 400
+    service_info = zc.get_service_info(type_, registration_name)
+    assert service_info is not None
+    assert service_info.port == 400
     browser.cancel()
 
     zc.close()
@@ -771,17 +789,17 @@ def test_service_browser_listeners_update_service():
     callbacks = []
 
     class MyServiceListener(r.ServiceListener):
-        def add_service(self, zc, type_, name) -> None:
+        def add_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("add", type_, name))
 
-        def remove_service(self, zc, type_, name) -> None:
+        def remove_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("remove", type_, name))
 
-        def update_service(self, zc, type_, name) -> None:
+        def update_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("update", type_, name))
@@ -795,7 +813,7 @@ def test_service_browser_listeners_update_service():
     address = socket.inet_aton(address_parsed)
     info = ServiceInfo(type_, registration_name, 80, 0, 0, desc, "ash-2.local.", addresses=[address])
 
-    def mock_incoming_msg(records) -> r.DNSIncoming:
+    def mock_incoming_msg(records: Iterable[r.DNSRecord]) -> r.DNSIncoming:
         generated = r.DNSOutgoing(const._FLAGS_QR_RESPONSE)
         for record in records:
             generated.add_answer_at_time(record, 0)
@@ -832,13 +850,13 @@ def test_service_browser_listeners_no_update_service():
     registration_name = "xxxyyy.%s" % type_
     callbacks = []
 
-    class MyServiceListener:
-        def add_service(self, zc, type_, name) -> None:
+    class MyServiceListener(r.ServiceListener):
+        def add_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("add", type_, name))
 
-        def remove_service(self, zc, type_, name) -> None:
+        def remove_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("remove", type_, name))
@@ -852,7 +870,7 @@ def test_service_browser_listeners_no_update_service():
     address = socket.inet_aton(address_parsed)
     info = ServiceInfo(type_, registration_name, 80, 0, 0, desc, "ash-2.local.", addresses=[address])
 
-    def mock_incoming_msg(records) -> r.DNSIncoming:
+    def mock_incoming_msg(records: Iterable[r.DNSRecord]) -> r.DNSIncoming:
         generated = r.DNSOutgoing(const._FLAGS_QR_RESPONSE)
         for record in records:
             generated.add_answer_at_time(record, 0)
@@ -935,7 +953,7 @@ async def test_generate_service_query_suppress_duplicate_questions():
         10000,
         f'known-to-other.{name}',
     )
-    other_known_answers = {answer}
+    other_known_answers: Set[r.DNSRecord] = {answer}
     zc.question_history.add_question_at_time(question, now, other_known_answers)
     assert zc.question_history.suppresses(question, now, other_known_answers)
 
@@ -1031,17 +1049,17 @@ def test_service_browser_matching():
     callbacks = []
 
     class MyServiceListener(r.ServiceListener):
-        def add_service(self, zc, type_, name) -> None:
+        def add_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("add", type_, name))
 
-        def remove_service(self, zc, type_, name) -> None:
+        def remove_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("remove", type_, name))
 
-        def update_service(self, zc, type_, name) -> None:
+        def update_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("update", type_, name))
@@ -1058,7 +1076,7 @@ def test_service_browser_matching():
         not_match_type_, not_match_registration_name, 80, 0, 0, desc, "ash-2.local.", addresses=[address]
     )
 
-    def mock_incoming_msg(records) -> r.DNSIncoming:
+    def mock_incoming_msg(records: Iterable[r.DNSRecord]) -> r.DNSIncoming:
         generated = r.DNSOutgoing(const._FLAGS_QR_RESPONSE)
         for record in records:
             generated.add_answer_at_time(record, 0)
@@ -1113,17 +1131,17 @@ def test_service_browser_expire_callbacks():
     callbacks = []
 
     class MyServiceListener(r.ServiceListener):
-        def add_service(self, zc, type_, name) -> None:
+        def add_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("add", type_, name))
 
-        def remove_service(self, zc, type_, name) -> None:
+        def remove_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("remove", type_, name))
 
-        def update_service(self, zc, type_, name) -> None:
+        def update_service(self, zc, type_, name) -> None:  # type: ignore[no-untyped-def]
             nonlocal callbacks
             if name == registration_name:
                 callbacks.append(("update", type_, name))
@@ -1148,7 +1166,7 @@ def test_service_browser_expire_callbacks():
         addresses=[address],
     )
 
-    def mock_incoming_msg(records) -> r.DNSIncoming:
+    def mock_incoming_msg(records: Iterable[r.DNSRecord]) -> r.DNSIncoming:
         generated = r.DNSOutgoing(const._FLAGS_QR_RESPONSE)
         for record in records:
             generated.add_answer_at_time(record, 0)
